#!/usr/bin/python
'''データベースのドライバ

    * sqlalchemyのデータベースエンジンを返す関数が入ってる
    * ぶっちゃけ、sqlite以外に対応する気はあんまりない
    * もしかしたらユーザーとグループの管理だけはmysqlとかに対応するかもしれない
    * アプリは廃棄可能性を保持したいので、絶対にファイルベースが良い
    * get_engine関数がユーザー管理用データベースのエンジンを返す
    * get_test_engine関数がユーザー管理用データベースのテスト用エンジンを返す
    * get_app_engine関数がアプリのデータベースのエンジンを返す(sqlite限定)
'''
