<!DOCTYPE html>
<html>
    <head>
        <meta charset='utf-8'>
        <meta name='viewport' content='width=device-width, initial-scale=1'>
        <title></title>
    </head>
    <body>
{% block header %}
    <header>
        <img src="/mtm-static/logo.svg" id="logo">
    </header>
{% endblock %}
{% block content %}
{% endblock %}
    </body>
</html>
