form {
    #image-form {
        display: grid;
        grid-template-columns: 80px 1fr;
        grid-gap: 16px;
        align-items: center;
        input{
            display: none;
        }
        img {
            display: block;
            width: 80px;
            height: 80px;
            border-radius: 40px;
        }
        .button {
            display: flex;
            background: var(--accent-background);
            color: var(--main-background);
            font-weight: bold;
            height: 32px;
            width: 160px;
            border-radius: 4px;
            justify-content: center;
            align-items: center;
        }
    }
    input[type = 'text'],
    input[type = 'password'],
    input[type = 'email'] {
        height: 32px;
        line-height: 32px;
        padding: 0 8px;
        box-sizing: border-box;
        display: block;
        border: none;
        border-bottom: 2px solid #0000;
        outline: none;
        transition: border-bottom 0.2s;
        &:focus {
            border-bottom: 2px solid var(--accent-background);
        }
        @include pc{
            width: 200px;
        }
        @include sp{
            width: 100%;
        }
    }
    dl{
        dt{
            font-weight: bold;
            font-size: 0.8rem;
        }
        dd{
            margin: 0;
            padding: 16px 24px 32px;
        }
    }
    button[type='submit'] {
        width: 160px;
    }
    .permission{
        label{
            display: grid;
            grid-template-columns: 24px 1fr;
            height: 32px;
            input[type='checkbox'] {
                width: 12px;
                height: 12px;
                margin: 10px 6px;
            }
            div{
                line-height: 32px;
            }
        }
    }
    @include pc{
        padding: 32px;
    }
}
