{% extends 'base.html' %}
{% block header %}
    {% include 'header.html' %}
{% endblock %}
{% block content %}
{% if error == None %}
{% set post = request.post() %}
{% else %}
{% set post = {} %}
{% endif %}
<div id='content'>
    {% if request.user.id == user.id %}
        <h2 class='mini-title dark'>設定</h2>
    {% else %}
        <h2 class='mini-title dark'>{{ user.name }}の設定</h2>
    {% endif %}
    <div class="inner">
        <form method='POST' action='' enctype='multipart/form-data' class="tight">
            <dl>
                <dt>アイコン</dt>
                <dd>
                    <div id='image-form'>
                        <img src="{{ dataurl(icon) }}" class="icon"/>
                        <label class='button'>
                            <input type='file' name='icon' accept='image/*' onchange="previewImage(this)" />
                            画像を選択
                        </label>
                        <script>
                            function previewImage(dom) {
                                document.querySelector("#image-form img").src=URL.createObjectURL(dom.files[0])
                            }
                        </script>
                    </div>
                </dd>
                <dt>ログイン名</dt>
                <dd>
                    <input type='text' name='screen_name' placeholder='ログイン名' value='{{ screen_name }}'/>
                </dd>
                <dt>名前</dt>
                <dd>
                    <input type='text' name='name' placeholder='名前' value='{{ name }}'/>
                </dd>
                {% if is_admin(request.user) %}
                <dt>権限の設定</dt>
                <dd class='permission'>
                    <label>
                        <input
                            name='user_create'
                            type='checkbox'
                            {{ 'checked' if user_create_permission(user) else ''}}
                        />
                        <div>ユーザーの招待</div>
                    </label>
                    <label>
                        <input
                            name='user_update'
                            type='checkbox'
                            {{ 'checked' if user_update_permission(user) else ''}}
                        />
                        <div>ユーザー情報の変更</div>
                    </label>
                    <label>
                        <input
                            name='user_delete'
                            type='checkbox'
                            {{ 'checked' if user_delete_permission(user) else ''}}
                        />
                        <div>ユーザーの追放</div>
                    </label>
                    <label>
                        <input
                            name='group_create'
                            type='checkbox'
                            {{ 'checked' if group_create_permission(user) else ''}}
                        />
                        <div>グループの作成</div>
                    </label>
                    <label>
                        <input
                            name='group_update'
                            type='checkbox'
                            {{ 'checked' if group_update_permission(user) else ''}}
                        />
                        <div>グループ情報の更新</div>
                    </label>
                    <label>
                        <input
                            name='group_delete'
                            type='checkbox'
                            {{ 'checked' if group_delete_permission(user) else ''}}
                        />
                        <div>グループの強制解散</div>
                    </label>
                    <label>
                        <input
                            name='admin'
                            type='checkbox'
                            {{ 'checked' if is_admin(user) else ''}}
                        />
                        <div>管理者権限（アプリ設定・権限設定の権限）</div>
                    </label>
                </dd>
            {% endif %}
            </dl>
            <button type='submit'>設定を変更</button>
            <!--
            <a href='{{ url('/users/'+user.id|string+'/delete') }}'>
                <button type='button'>ユーザーを削除</button>
            </a>
            -->
            {% if error %}
                <p class='error'>{{ error }}</p>
            {% endif %}
            {% if message %}
                <p class='message'>{{ message}}</p>
            {% endif %}
        </form>
    </div>
</div>
{% endblock %}
