header{
    height: 56px;
    display: grid;
    grid-template-columns: 1fr auto;
    background: var(--header-background);
    position: sticky;
    top: 0;
    color: var(--header-text);
    #logo{
        height: 40px;
        display: block;
    }
    #logo_container {
        padding: 8px 16px;
    }
    #user-menu{
        #menu-status{
            display: none;
        }
        label{
            padding: 8px 16px;
            display: grid;
            grid-gap: 8px;
            grid-template-columns: 32px 1fr;
            align-items: center;
            height: 40px;
            font-weight: bold;
            background: #0001;
            width: 160px;
        }
        .user-icon{
            width: 32px;
            height: 32px;
        }
    }
    menu {
        display: flex;
        opacity: 0;
        flex-direction: column;
        justify-content: flex-end;
        position: absolute;
        top: 40px;
        pointer-events: none;
        width: 200px;
        right: 0;
        display: block;
        margin: 0;
        padding: 16px;
        transition: all 0.2s;
        background: var(--main-background);
        box-shadow: 0 0 10px #0004;
        & > div {
            border-bottom: 1px solid var(--main-decoration);
            padding-bottom: 8px;
            margin-bottom: 8px;
        }
        & div:last-child {
            border: none;
            padding-bottom: 0;
            margin-bottom: 0;
        }
        a {
            display: grid;
            grid-template-columns: 32px 1fr;
            grid-gap: 8px;
            width: 100%;
            height:40px;
            justify-content: center;
            align-items: center;
            text-decoration: none;
            padding: 0 4px;
            font-weight: bold;
            color: var(--main-text);
            transition: all 0.2s;
            svg {
                width: 32px;
                height: 32px;
                fill: var(--main-text);
                transition: all 0.2s;
            }
            &:hover{
                color: var(--main-color);
                svg{
                    fill: var(--main-color);
                }
            }
        }
    }
    #menu-status:checked ~ menu {
        opacity: 1;
        pointer-events: all;
        top: 64px;
    }
}
