#modal-switch {
    display: none;
    &:checked ~ .modal {
        display: flex;
    }
}
.modal {
    position: fixed;
    top:0;
    left:0;
    right:0;
    bottom:0;
    width: 100vw;
    height: 100vh;
    display: none;
    .background{
        display: block;
        background: #0003;
        width: 100%;
        height: 100%;
        position: absolute;
        top: 0;
        left: 0;
    }
    .inner{
        padding: 24px;
        background: #fff;
        margin: 100px auto;
        width: calc(100% - 64px);
        max-width: 600px;
        position: absolute;
        left: 0;
        right: 0;
        overflow-y: scroll;
        z-index: 2;
    }
    input[type='search'] {
        width: 100%;
        box-sizing: border-box;
        height: 32px;
        line-height: 32px;
        border: none;
        outline: none;
        border-bottom-width: 2px;
        border-bottom-style: solid;
        border-bottom-color: #0000;
        transition: all 0.2s;
        &:focus{
            border-bottom-color: var(--accent-background);
        }
    }
    .modal-submit{
        display: flex;
        justify-content: center;
        margin:16px 24px;
        button{
            width: 120px;
            margin: 0 8px;
        }
    }
    @include pc{
        .two-columns{
            display: grid;
            grid-template-columns: 1fr 1fr;
            grid-gap: 16px;
            h4{
                margin: 8px 0 4px;
            }
        }
    }
}
